@@ -16,12 +16,12 @@ finally:
     del version, PackageNotFoundError
 
 
-from .binaryconfusionmatrix import BinaryConfusionMatrix  # noqa: F401
-from .confusionmatrix import ConfusionMatrix  # noqa: F401
-from .constants import *  # noqa: F401, F403
-from .data_methods import *  # noqa: F401, F403
-from .display import print_grid, print_image  # noqa: F401
-from .file_methods import *  # noqa: F401, F403
-from .general import *  # noqa: F401, F403
-from .goudapath import GoudaPath  # noqa: F401
-from .moving_stats import *  # noqa: F401, F403
+from gouda.binaryconfusionmatrix import BinaryConfusionMatrix  # noqa: F401
+from gouda.confusionmatrix import ConfusionMatrix  # noqa: F401
+from gouda.constants import *  # noqa: F401, F403
+from gouda.data_methods import *  # noqa: F401, F403
+from gouda.display import print_grid, print_image  # noqa: F401
+from gouda.file_methods import *  # noqa: F401, F403
+from gouda.general import *  # noqa: F401, F403
+from gouda.goudapath import GoudaPath  # noqa: F401
+from gouda.moving_stats import *  # noqa: F401, F403
