@@ -3,7 +3,7 @@ import colorama
 import numpy as np
 import warnings
 
-from .data_methods import num_digits
+from gouda.data_methods import num_digits
 
 __author__ = "Sean Mullan"
 __copyright__ = "Sean Mullan"
